==> nextcloud-31.0.4-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/federation/l10n/de.js <==
OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Der Liste der vertrauenswürdigen Server hinzugefügt",
    "No server found with ID: %s" : "Kein Server mit folgender ID gefunden: %s",
    "Could not remove server" : "Server konnte nicht entfernt werden",
    "Server is already in the list of trusted servers." : "Server ist bereits in der Liste der vertrauenswürdigen Server.",
    "No server to federate with found" : "Es wurde kein Server zum Verbinden per Federation gefunden",
    "Could not add server" : "Konnte Server nicht hinzufügen",
    "Trusted servers" : "Vertrauenswürdige Server",
    "Federation" : "Federation",
    "Federation allows you to connect with other trusted servers to exchange the account directory." : "Federation ermöglicht die Verbindung mit anderen vertrauenswürdigen Servern, um das Kontenverzeichnis auszutauschen.",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing." : "Federation ermöglicht es dir, dich mit anderen vertrauenswürdigen Servern zu verbinden, um das Kontoverzeichnis auszutauschen. Dies wird zum Beispiel für die automatische Vervollständigung externer Konten beim Federated-Sharing verwendet.",
    "External documentation for Federated Cloud Sharing" : "Externe Dokumentation für das Teilen über Federated Cloud",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "Federation ermöglicht es dir, dich mit anderen vertrauenswürdigen Servern zu verbinden, um das Kontoverzeichnis auszutauschen. Dies wird zum Beispiel für die automatische Vervollständigung externer Konten beim Federated-Sharing verwendet. Es ist nicht erforderlich einen Server als vertrauenswürdig hinzuzufügen, um eine \"federated\" Freigabe zu erstellen.",
    "Each server must validate the other. This process may require a few cron cycles." : "Jeder Server muss den anderen validieren. Dieser Vorgang kann einige Cron-Zyklen benötigen.",
    "+ Add trusted server" : "+ Vertrauenswürdigen Server hinzufügen",
    "Trusted server" : "Vertrauenswürdiger Server",
    "Add" : "Hinzufügen"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/federation/l10n/de.js <==
OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Der Liste der vertrauenswürdigen Server hinzugefügt",
    "No server found with ID: %s" : "Kein Server mit folgender ID gefunden: %s",
    "Could not remove server" : "Server konnte nicht entfernt werden",
    "Server is already in the list of trusted servers." : "Server ist bereits in der Liste der vertrauenswürdigen Server.",
    "No server to federate with found" : "Es wurde kein Server zum Verbinden per Federation gefunden",
    "Could not add server" : "Server konnte nicht hinzugefügt werden",
    "Trusted servers" : "Vertrauenswürdige Server",
    "Federation" : "Federation",
    "Federation allows you to connect with other trusted servers to exchange the account directory." : "Federation ermöglicht die Verbindung mit anderen vertrauenswürdigen Servern, um das Kontenverzeichnis auszutauschen.",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing." : "Federation ermöglicht es dir, dich mit anderen vertrauenswürdigen Servern zu verbinden, um das Kontoverzeichnis auszutauschen. Dies wird zum Beispiel für die automatische Vervollständigung externer Konten beim Federated-Sharing verwendet.",
    "External documentation for Federated Cloud Sharing" : "Externe Dokumentation für das Teilen über Federated Cloud",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "Federation ermöglicht es dir, dich mit anderen vertrauenswürdigen Servern zu verbinden, um das Kontoverzeichnis auszutauschen. Dies wird zum Beispiel für die automatische Vervollständigung externer Konten beim Federated-Sharing verwendet. Es ist nicht erforderlich einen Server als vertrauenswürdig hinzuzufügen, um eine \"federated\" Freigabe zu erstellen.",
    "Each server must validate the other. This process may require a few cron cycles." : "Jeder Server muss den anderen validieren. Dieser Vorgang kann einige Cron-Zyklen benötigen.",
    "+ Add trusted server" : "+ Vertrauenswürdigen Server hinzufügen",
    "Trusted server" : "Vertrauenswürdiger Server",
    "Add" : "Hinzufügen"
},
"nplurals=2; plural=(n != 1);");
